Notebook Narratives
===================

.. contents:: Contents
   :local:

Description
-----------

The Notebook Narratives explore uses of the Jupyter Notebook in a variety of
applications.

Narrative examples
------------------

- Using the Notebook for data exploration
- Using extensions and widgets
- Using nbconvert for code execution and workflow simplification
- Using nbconvert for publishing
- Using multiple language kernels

.. note::

    We're actively working on this section of the documentation to improve
    it for you. Thanks for your patience.
